summaryrefslogtreecommitdiffstats
path: root/karbon/core/vobject.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /karbon/core/vobject.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'karbon/core/vobject.h')
-rw-r--r--karbon/core/vobject.h44
1 files changed, 22 insertions, 22 deletions
diff --git a/karbon/core/vobject.h b/karbon/core/vobject.h
index 9aa6885a..93a3ab1f 100644
--- a/karbon/core/vobject.h
+++ b/karbon/core/vobject.h
@@ -26,7 +26,7 @@
#include <dcopobject.h>
#include <koffice_export.h>
-class QDomElement;
+class TQDomElement;
class VDocument;
class VFill;
class VPainter;
@@ -44,7 +44,7 @@ class KoGenStyle;
* have the ability to draw itself using a painter, perform
* hit detection, transform on demand, clone and load/save itself.
* Also each object manages its own bounding box and keeps track of its
- * parent object.
+ * tqparent object.
*/
class KARBONBASE_EXPORT VObject
{
@@ -57,22 +57,22 @@ public:
hidden_locked = 3, /**< hidden and locked (r/o) */
deleted = 4, /**< deleted, nearly dead */
- // shape specific states:
+ // tqshape specific states:
selected = 5, /**< visible, active and can be manipulated by tools */
edit = 6 /**< visible, active and is currently manipulated by a tool */
};
/**
* Constructs a new object that is child of parent and has the given state.
*
* @param parent the new object's parent
* @param state the new object's state
*/
- VObject( VObject* parent, VState state = edit );
+ VObject( VObject* tqparent, VState state = edit );
/**
* Copy constructor.
* Copies parent, state and name of given object.
*
* @param obj the object to copy properties from
*/
@@ -124,27 +124,27 @@ public:
* This function is public so visitors can access it themself at the right
* time when they manipulate many VSegments.
*/
- void invalidateBoundingBox()
+ void tqinvalidateBoundingBox()
{
m_boundingBoxIsInvalid = true;
if( m_parent )
- m_parent->invalidateBoundingBox();
+ m_parent->tqinvalidateBoundingBox();
}
/**
* Sets a new parent object.
*
* @param parent the new parent object
*/
- void setParent( VObject* parent ) { m_parent = parent; }
+ void setParent( VObject* tqparent ) { m_parent = tqparent; }
/**
* Returns pointer to current parent object.
*
* @return pointer to current parent object or 0 if no parent object is set
*/
- VObject* parent() const { return m_parent; }
+ VObject* tqparent() const { return m_parent; }
/**
* Get the state the object is in.
@@ -195,7 +195,7 @@ public:
*
* @param element the DOM element to which the attributes are saved
*/
- virtual void save( QDomElement& element ) const;
+ virtual void save( TQDomElement& element ) const;
/**
* Save this object's state to OpenDocument.
@@ -212,7 +212,7 @@ public:
*
* @param element the DOM element from which the attributes are read
*/
- virtual void load( const QDomElement& element );
+ virtual void load( const TQDomElement& element );
/**
* Load this object's state from OpenDocument and initialize
@@ -221,7 +221,7 @@ public:
* @param element the DOM element to read attributes from
* @param context FIXME
*/
- virtual bool loadOasis( const QDomElement &element, KoOasisLoadingContext &context );
+ virtual bool loadOasis( const TQDomElement &element, KoOasisLoadingContext &context );
/**
* Create an exact copy of this object.
@@ -254,19 +254,19 @@ public:
*
* @return the object's name
*/
- virtual QString name() const;
+ virtual TQString name() const;
/**
* Sets the object's name to a given new name.
*
* @param s the new object name
*/
- void setName( const QString &s );
+ void setName( const TQString &s );
/**
* Return document the object belongs to.
*
* @return pointer to parent document or 0 if object does not belong to a document
*/
VDocument *document() const;
@@ -277,7 +277,7 @@ protected:
* @param style FIXME
* @param context FIXME
*/
- void addStyles( const QDomElement* style, KoOasisLoadingContext & context );
+ void addStyles( const TQDomElement* style, KoOasisLoadingContext & context );
virtual void saveOasisFill( KoGenStyles &mainStyles, KoGenStyle &stylesojectauto ) const;
@@ -57,22 +57,22 @@ public:
};
/**
- * Constructs a new object that is child of parent and has the given state.
+ * Constructs a new object that is child of tqparent and has the given state.
*
@@ -57,22 +57,22 @@ public:
*
- * @param parent the new object's parent
+ * @param tqparent the new object's tqparent
* @param state the new object's state
*/
@@ -57,22 +57,22 @@ public:
/**
* Copy constructor.
- * Copies parent, state and name of given object.
+ * Copies tqparent, state and name of given object.
*
* @param obj the object to copy properties from
@@ -124,27 +124,27 @@ public:
}
/**
- * Sets a new parent object.
+ * Sets a new tqparent object.
*
@@ -124,27 +124,27 @@ public:
*
- * @param parent the new parent object
+ * @param tqparent the new tqparent object
*/
@@ -124,27 +124,27 @@ public:
/**
- * Returns pointer to current parent object.
+ * Returns pointer to current tqparent object.
*
@@ -124,27 +124,27 @@ public:
*
- * @return pointer to current parent object or 0 if no parent object is set
+ * @return pointer to current tqparent object or 0 if no tqparent object is set
*/
@@ -254,19 +254,19 @@ public:
* Return document the object belongs to.
*
- * @return pointer to parent document or 0 if object does not belong to a document
+ * @return pointer to tqparent document or 0 if object does not belong to a document
*/
VDocument *document() const;